pub struct Importer {
pub corpus: Corpus,
pub backend: Backend,
pub cwd: PathBuf,
pub active_prefixes: HashSet<String>,
}Expand description
Struct for performing corpus imports into CorTeX
Fields
corpus: Corpusa Corpus to be imported, containing all relevant metadata
backend: Backenda Backend on which to persist the import into the Task store
cwd: PathBufthe current working directory, to resolve relative paths
active_prefixes: HashSet<String>the known prefixes of top-level directories to import used to avoid re-examining existing directories.
Implementations
Sourceimpl Importer
impl Importer
Sourcepub fn walk_import(&mut self) -> Result<usize, Box<dyn Error>>
pub fn walk_import(&mut self) -> Result<usize, Box<dyn Error>>
Given a CorTeX-topology corpus, walk the file system and import it into the Task store
Sourcepub fn new_task(&self, entry: &str) -> NewTask
pub fn new_task(&self, entry: &str) -> NewTask
Create a new TODO task for the “import” service and the Importer-specified corpus (should get marked as “NoProblem” once the extension is completed)